Changelog
---------
0.0.20 (2018-12-11)
~~~~~~~~~~~~~~~~~~~

- Uses a multiple tree select widget for policy descriptors.
  [msom]

0.0.19 (2018-12-10)
~~~~~~~~~~~~~~~~~~~

- Adds descriptors.
  [msom]

- Fixes the click area of collapsible tables.
  [msom]

0.0.18 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Import data files in alphabetical order.
  [msom]

- Fixes XLSX import for quasi-empty string cells.
  [msom]

0.0.17 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Fixes data import.
  [msom]

0.0.16 (2018-12-09)
~~~~~~~~~~~~~~~~~~~

- Reorganizes the vote details view.
  [msom]

- Makes groups of vote details collapsible.
  [msom]

0.0.15 (2018-11-25)
~~~~~~~~~~~~~~~~~~~

- Fixes switching the extended filters.
  [msom]

0.0.14 (2018-11-21)
~~~~~~~~~~~~~~~~~~~

- Fixes displaying yeas and nays of council positions.
  [msom]

0.0.13 (2018-11-21)
~~~~~~~~~~~~~~~~~~~

- Improves the XLSX import.
  [msom]

0.0.12 (2018-11-20)
~~~~~~~~~~~~~~~~~~~

- Allows to search for BFS and procedure numbers.
  [msom]

- Allows to search by council positions.
  [msom]

- Adds a full text search option.
  [msom]

- Fixes the formatting of BFS numbers.
  [msom]

0.0.11 (2018-11-05)
~~~~~~~~~~~~~~~~~~~

- Adds resolution and realization attachments.
  [msom]

- Reorders the votes columns.
  [msom]

- Only shows the top level of the descriptor in the votes view.
  [msom]

- Uses the latest onegov.form.
  [msom]

0.0.10 (2018-10-07)
~~~~~~~~~~~~~~~~~~~

- Use tsquery phrases for multipley fulltext terms.
  [msom]

0.0.9 (2018-10-07)
~~~~~~~~~~~~~~~~~~~

- Uses prostgres for keyword filtering instead of elastic search.
  [msom]

0.0.8 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Use a wider range of MIME types when updating the dataset.
  [msom]

0.0.7 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Adds full text search support for attachments.
  [msom]

- Adds voting booklet attachments.
  [msom]

- Adds a CLI command for importing attachments.
  [msom]

- Makes the update, export and delete vote views to be indifferent to the filters.
  [msom]

- Handles search beeing unavailable.
  [msom]

- Sorts full text search results by rank.
  [msom]

0.0.6 (2018-09-23)
~~~~~~~~~~~~~~~~~~~

- Adds search.
  [msom]

- Uses XLSX for import.
  [msom]

- Uses excel format for CSV export.
  [msom]

0.0.5 (2018-09-18)
~~~~~~~~~~~~~~~~~~~

- Adds XLSX export.
  [msom]

- Improves UI.
  [msom]

- Enables English.
  [msom]

0.0.4 (2018-09-03)
~~~~~~~~~~~~~~~~~~~

- Styles content pages.
  [msom]

0.0.3 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Improves vote(s) views.
  [msom]

- Adds editor options.
  [msom]

- Fixes votes pagination.
  [msom]

0.0.2 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Adds the GitHub deploy key.
  [msom]

0.0.1 (2018-08-30)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [msom]
